@@ -22,7 +22,15 @@
 #include <QQmlContext>
 #include <QQuickStyle>
 #include <QQuickWindow>
+#define HAVE_KICONTHEME __has_include(<KIconTheme>)
+#if HAVE_KICONTHEME
+#include <KIconTheme>
+#endif
 
+#define HAVE_STYLE_MANAGER __has_include(<KStyleManager>)
+#if HAVE_STYLE_MANAGER
+#include <KStyleManager>
+#endif
 static void raiseWindow(QWindow *window)
 {
     KWindowSystem::updateStartupId(window);
@@ -31,6 +39,9 @@ static void raiseWindow(QWindow *window)
 
 int main(int argc, char *argv[])
 {
+#if HAVE_KICONTHEME
+    KIconTheme::initTheme();
+#endif
     QGuiApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
     QApplication app(argc, argv);
     KLocalizedString::setApplicationDomain(QByteArrayLiteral("merkuro"));
@@ -43,8 +54,12 @@ int main(int argc, char *argv[])
         QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
     }
 
-#if defined(Q_OS_WIN) || defined(Q_OS_MAC)
+#if HAVE_STYLE_MANAGER
+    KStyleManager::initStyle();
+#else // !HAVE_STYLE_MANAGER
+#if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
     QApplication::setStyle(QStringLiteral("breeze"));
+#endif
 #endif
 
     KAboutData aboutData(
@@ -58,7 +73,7 @@ int main(int argc, char *argv[])
         // The license this code is released under.
         KAboutLicense::GPL_V3,
         // Copyright Statement.
-        i18n("(c) KDE Community 2021"));
+        i18n("(c) KDE Community 2021-2024"));
     aboutData.setBugAddress("https://bugs.kde.org/enter_bug.cgi?format=guided&product=merkuro&version=" + QStringLiteral(MERKURO_VERSION_STRING).toUtf8());
     aboutData.addAuthor(i18nc("@info:credit", "Carl Schwan"),
                         i18nc("@info:credit", "Maintainer"),
@@ -90,6 +105,7 @@ int main(int argc, char *argv[])
     QQmlApplicationEngine engine;
 
     QObject::connect(&service, &KDBusService::activateRequested, &engine, [&engine, &parser](const QStringList &arguments, const QString &workingDirectory) {
+        Q_UNUSED(workingDirectory)
         parser.parse(arguments);
         const auto rootObjects = engine.rootObjects();
 
@@ -138,7 +154,5 @@ int main(int argc, char *argv[])
         }
     }
 
-    QDBusConnection::sessionBus().interface()->startService(QStringLiteral("org.kde.merkuroac"));
-
     return app.exec();
 }
