@@ -16,7 +16,15 @@
 #include <QQmlContext>
 #include <QQuickStyle>
 #include <QQuickWindow>
+#define HAVE_KICONTHEME __has_include(<KIconTheme>)
+#if HAVE_KICONTHEME
+#include <KIconTheme>
+#endif
 
+#define HAVE_STYLE_MANAGER __has_include(<KStyleManager>)
+#if HAVE_STYLE_MANAGER
+#include <KStyleManager>
+#endif
 static void raiseWindow(QWindow *window)
 {
     KWindowSystem::updateStartupId(window);
@@ -25,6 +33,9 @@ static void raiseWindow(QWindow *window)
 
 int main(int argc, char *argv[])
 {
+#if HAVE_KICONTHEME
+    KIconTheme::initTheme();
+#endif
     QGuiApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
     QApplication app(argc, argv);
     KLocalizedString::setApplicationDomain(QByteArrayLiteral("merkuro"));
@@ -37,8 +48,12 @@ int main(int argc, char *argv[])
         QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
     }
 
-#if defined(Q_OS_WIN) || defined(Q_OS_MAC)
+#if HAVE_STYLE_MANAGER
+    KStyleManager::initStyle();
+#else // !HAVE_STYLE_MANAGER
+#if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
     QApplication::setStyle(QStringLiteral("breeze"));
+#endif
 #endif
 
     KAboutData aboutData(
@@ -52,7 +67,7 @@ int main(int argc, char *argv[])
         // The license this code is released under.
         KAboutLicense::GPL_V3,
         // Copyright Statement.
-        i18n("(c) KDE Community 2021"));
+        i18n("(c) KDE Community 2021-2024"));
     aboutData.setBugAddress("https://bugs.kde.org/enter_bug.cgi?format=guided&product=merkuro&version=" + QStringLiteral(MERKURO_VERSION_STRING).toUtf8());
     aboutData.addAuthor(i18nc("@info:credit", "Carl Schwan"),
                         i18nc("@info:credit", "Maintainer"),
@@ -76,10 +91,10 @@ int main(int argc, char *argv[])
     const auto args = parser.positionalArguments();
     QQmlApplicationEngine engine;
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
-    if (args.length() > 0) {
+    if (!args.isEmpty()) {
         qmlRegisterType<MessageHandler>("org.kde.merkuro.mail.desktop", 1, 0, "MessageHandler");
         QObject::connect(&engine, &QQmlApplicationEngine::quit, &app, &QCoreApplication::quit);
-        engine.load(QUrl(QStringLiteral("qrc:/qml/desktopactions/openmbox.qml")));
+        engine.loadFromModule("org.kde.merkuro.mail", "OpenMbox");
         const auto rootObjects = engine.rootObjects();
         if (rootObjects.isEmpty()) {
             return -1;
@@ -94,7 +109,7 @@ int main(int argc, char *argv[])
             messageHandler->open(file);
         }
     } else {
-        engine.load(QUrl(QStringLiteral("qrc:/qml/app/main.qml")));
+        engine.loadFromModule("org.kde.merkuro.mail", "Main");
 
         QObject::connect(&service,
                          &KDBusService::activateRequested,
